@@ -1,4 +1,3 @@
-from mingus.midi import fluidsynth
 from mingus.containers.Note import Note
 from random import randrange
 from mingus.containers.Track import Track
@@ -35,6 +34,10 @@ class Instrument:
 		if 'step' in parameters:
 			self.step = parameters["step"]
 
+	def import_fluidsynth(self):
+		global fluidsynth
+		from mingus.midi import fluidsynth
+
 	def add_rest(self, state):
 		if state["tick"] == 0:
 			if hasattr(self, "bar"):
@@ -81,8 +84,8 @@ class Instrument:
 			b.key = state["key"]
 			self.bar = b
 		let_ring = False
-		#if 'let_ring' not in self.params:
 		self.stop_playing_notes()
+		#if 'let_ring' not in self.params:
 		#else:
 		#	if not self.params['let_ring']:
 		#		self.stop_playing_notes()
