@@ -1,7 +1,10 @@
 class Movement:
 
 	blocks = []
+	progressions = []
 	b_counter = 0
+	p_counter = 0
+
 	loop = 1
 	default_bpm = 120
 	default_wildness = 0.5
@@ -18,6 +21,9 @@ class Movement:
 		block.wildness = self.default_wildness
 		self.blocks.append(block)
 
+	def add_progression(self, progression):
+		self.progressions.append(progression)
+
 	def set_default_bpm(self, bpm):
 		self.default_bpm = bpm
 	
@@ -33,6 +39,7 @@ Returns None if there is no next block."""
 		if len(self.blocks) > 0:
 			if self.loop > 0:
 				r = self.get_block()
+				r.progressions = self.get_progression()
 				self.b_counter += 1
 				if self.b_counter == len(self.blocks):
 					self.b_counter = 0
@@ -42,3 +49,14 @@ Returns None if there is no next block."""
 
 	def get_block(self):
 		return self.blocks[self.b_counter]
+
+	def get_progression(self):
+		if len(self.progressions) > 0:
+			p = self.progressions[self.p_counter]
+			self.p_counter += 1
+			if self.p_counter == len(self.progressions):
+				self.p_counter = 0
+			return p
+
+		return None
+
