@@ -1,5 +1,5 @@
 from Instrument import Instrument
-from mingus.containers.NoteContainers import NoteContainer
+from mingus.containers.NoteContainer import NoteContainer
 from random import random, randrange
 
 class ChordInstrument(Instrument):
